@@ -386,6 +386,20 @@ VideoWindow::state() const
     return m_media->state();
 }
 
+bool
+VideoWindow::isActiveState() const
+{
+    return isActiveState(state());
+}
+
+bool
+VideoWindow::isActiveState(Phonon::State s) const
+{
+    return (s == Phonon::PlayingState ||
+            s == Phonon::PausedState ||
+            s == Phonon::BufferingState);
+}
+
 qreal
 VideoWindow::volume() const
 {
@@ -726,6 +740,7 @@ VideoWindow::event( QEvent* event )
     {
     case QEvent::Leave:
         m_cursorTimer->stop();
+        qApp->restoreOverrideCursor();
         qDebug() << "stop cursorTimer";
         break;
     case QEvent::FocusOut:
